@@ -20,15 +20,15 @@ Options:
                           [Default: 1e5]
   --frag-size-mean=<fsm>  Mean fragment size of input gDNA (bp)
                           [Default: 10000]
-  --frag-size-sp=<fss>    Fragment size spread of input gDNA (bp)
-                          [Default: 10000]
+  --frag-size-sd=<fss>    Fragment size standard deviation of input gDNA (bp)
+                          [Default: 1000]
   --frag-size-min=<fsa>   Min fragment size of input gDNA (bp)
                           [Default: 8000]
   --frag-size-max=<fsa>   Min fragment size of input gDNA (bp)
                           [Default: 20000]
   --frag-bc-mean=<fbm>    Mean fragment-to-barcode count
                           [Default: 5]
-  --frag-bc-sd=<fbs>      Stdev fragment-to-barcode count
+  --frag-bc-sd=<fbs>      Standard deviation of fragment-to-barcode count
                           [Default: 1]
   --art-paired            art_illumina "paired"  parameter.
   --art-len=<al>          art_illumina "len" parameter.
@@ -44,6 +44,8 @@ Options:
                           [Default: None]
   --tmp-dir=<td>          Temporary directory. 
                           [Default: .sim_reads]
+  --read-name=<bft>       Read name format
+                          [Default: {readID} BX:Z:{barcodeID}]
   -n=<n>                  Number of cpus. 
                           [Default: 1]
   --debug                 Debug mode (no subprocesses verbose output).
@@ -149,17 +151,12 @@ def main(args):
     exe = 'art_illumina'
     if find_executable(exe) == '':
         raise IOError('Cannot find executable: {}'.format(exe))
-    ## temp dir
-    if not os.path.isdir(args['--tmp-dir']):
-        os.makedirs(args['--tmp-dir'])
     
     # load tables
     ## table mapping taxa to genomes
     genome_table = SimReads.load_genome_table(args['<genome_table>'])
     ## table of taxon relative abundances
     abund_table = SimReads.load_abund_table(args['<abund_table>'])
-    x = abund_table.Community[0]
-    abund_table = abund_table.loc[abund_table.Community == x,]
 
     # Sim Params
     ## random seed
@@ -167,6 +164,25 @@ def main(args):
         rndSeed = None
     else:
         rndSeed = int(args['--rndSeed'])
+
+    # simulating per community
+    comms = abund_table.Community.unique()
+    for comm in comms:
+        logging.info('Simulating reads for community: {}'.format(comm))
+        comm_tbl = abund_table.loc[abund_table.Community == comm,]
+        sim_per_community(args, comm_id = comm,
+                          abund_table = comm_tbl,
+                          genome_table = genome_table,
+                          rndSeed = rndSeed)
+
+
+def sim_per_community(args, comm_id, abund_table, genome_table, rndSeed):
+    # I/O
+    outdir = os.path.join(args['<output_dir>'], str(comm_id))
+    ## temp dir
+    tmp_dir = os.path.join(args['--tmp-dir'], str(comm_id))
+    if not os.path.isdir(tmp_dir):
+        os.makedirs(tmp_dir)
     
     ## batching by barcodes
     ### creating barcode ID array
@@ -175,7 +191,8 @@ def main(args):
     ### simulating barcodes
     func = partial(SimHtReads.sim_barcode_reads,
                    genome_table=genome_table,
-                   abund_table=abund_table,                   
+                   abund_table=abund_table,
+                   tmp_dir=tmp_dir,
                    args=args,
                    rndSeed=rndSeed)
     barcodes = SimHtReads.bin_barcodes(barcodes,args['--barcode-chunks'])
@@ -187,13 +204,12 @@ def main(args):
     # flatten batched output
     (fq_files,tsv_files) = flatten(files)
     # combining all frag tsv
-    SimHtReads.combine_frag_tsv(tsv_files, args['<output_dir>'])
+    SimHtReads.combine_frag_tsv(tsv_files, outdir)
     # combining all reads
-    SimHtReads.combine_reads(fq_files, args['<output_dir>'])
+    SimHtReads.combine_reads(fq_files, outdir, name_fmt=args['--read-name'])
     # removing temp directory
     if args['--debug'] is False:
         rmtree(args['--tmp-dir'])
-
         
 def opt_parse(args=None):
     if args is None:        
