@@ -47,7 +47,7 @@ def bin_barcodes(barcodes, binsize=1000):
                        np.arange(0,barcodes.shape[0],binsize))
     return [barcodes[bins == x] for x in np.unique(bins)]
 
-def sim_barcode_reads(barcodes, genome_table, abund_table, args, rndSeed=None):
+def sim_barcode_reads(barcodes, genome_table, abund_table, tmp_dir, args, rndSeed=None):
     """Simulate reads for each fragment associated with each barcode
     Parameters
     ----------
@@ -79,12 +79,12 @@ def sim_barcode_reads(barcodes, genome_table, abund_table, args, rndSeed=None):
         # sim fragment sizes
         refs = sim_frags(refs, n_frags,
                          frag_size_loc=float(args['--frag-size-mean']),
-                         frag_size_scale=float(args['--frag-size-sp']),
+                         frag_size_sd=float(args['--frag-size-sd']),
                          frag_size_min=int(args['--frag-size-min']),
                          frag_size_max=int(args['--frag-size-max']))
 
         # parsing fragments
-        func = partial(parse_frags, barcode=barcode, out_dir=args['--tmp-dir'])
+        func = partial(parse_frags, barcode=barcode, out_dir=tmp_dir)
         frag_files = [func(refs.loc[refs['Taxon'] == taxon]) for taxon in refs['Taxon'].unique()]
         
         # simulating reads
@@ -238,7 +238,8 @@ def combine_frag_tsv(tsv_files, output_dir, debug=False):
             
     logging.info('File written: {}'.format(out_file))
 
-def combine_reads(fq_files, output_dir, debug=False):
+def combine_reads(fq_files, output_dir, name_fmt='{readID} BX:Z:{barcodeID}',
+                  debug=False):
     """ Concat all read files
     Parameters
     ----------
@@ -246,6 +247,8 @@ def combine_reads(fq_files, output_dir, debug=False):
         Iterable of fastq read files
     output_dir : str
         Final output directory for read files
+    name_fmt : str
+        How to format the read name. "{readID} BX:Z:{barcodeID}" will generate names such as "@ST-J00101:121:HYCGGBBXX:5:1101:30533:1191 BX:Z:A58B91C07D86"
     debug : bool
         Debug mode
     """    
@@ -260,28 +263,38 @@ def combine_reads(fq_files, output_dir, debug=False):
     if not os.path.isdir(output_dir):
         os.makedirs(output_dir)
     ## read1
-    R1_files = _combine_reads(R1_files, output_dir, 'R1.fq')
+    R1_files = _combine_reads(R1_files, output_dir, 'R1.fq', name_fmt)
     ## read2
     if R2_files is not None:
-        R2_files = _combine_reads(R2_files, output_dir, 'R2.fq')
+        R2_files = _combine_reads(R2_files, output_dir, 'R2.fq', name_fmt)
 
-def _combine_reads(read_files, out_dir, out_file):
+def _combine_reads(read_files, out_dir, out_file, name_fmt):
     """Combining temporary read files.
-    (eg., @ST-J00101:121:HYCGGBBXX:5:1101:30533:1191 BX:Z:A58B91C07D86).
+    eg., @ST-J00101:121:HYCGGBBXX:5:1101:30533:1191 BX:Z:A58B91C07D86
 
     """
-    #template = '@ST-J00101:136:FC706VJ:1:1:{}:{} BX:Z:{}'
     out_file = os.path.join(out_dir, out_file)
     with open(out_file, 'w') as outF:
         for i,F in enumerate(read_files):
             with open(F, 'r') as inF:
+                seq_len = 0
+                qual_len = 0
                 for ii,line in enumerate(inF):
-                    if ii % 4 == 0:
+                    if ii % 4 == 0:   # read header
                         line = line.split('-')
-                        outF.write('{} BX:Z:{}\n'.format(line[0],
-                                                         line[1]))
-                    else:
-                        outF.write(line)
+                        X = name_fmt.format(readID=line[0], barcodeID=line[1])
+                        outF.write(X + '\n')
+                        seq_len = 0
+                        qual_len = 0
+                        continue
+                    elif ii % 4 == 1:  # read sequence
+                        seq_len = len(line.rstrip())
+                    elif ii % 4 == 3:  # read quality
+                        qual_len = len(line.rstrip())
+                        if seq_len != qual_len:
+                            msg = 'Line {} in file {}: read-len != qual-len'
+                            raise ValueError(msg.format(ii, F))
+                    outF.write(line)
                         
     logging.info('File written: {}'.format(out_file))
         
@@ -299,7 +312,7 @@ def select_refs(n_frags, genome_table):
                             p=probs)
     return genome_table.loc[refs]
     
-def sim_frags(refs, n_frags, frag_size_loc, frag_size_scale,
+def sim_frags(refs, n_frags, frag_size_loc, frag_size_sd,
               frag_size_min, frag_size_max):
     """Simulating fragment sizes
     Parameters
@@ -310,19 +323,19 @@ def sim_frags(refs, n_frags, frag_size_loc, frag_size_scale,
         Number of fragments
     frag_size_loc : float
         Mean fragment size
-    frag_size_scale : float
+    frag_size_sd : float
         Stdev fragment size
     frag_size_min : float
         Min fragmen size (trun-norm distribution)
     frag_size_max : float
         Max fragmen size (trun-norm distribution)
     """
-    a = (frag_size_min - frag_size_loc) / frag_size_scale  # fraction of range smaller than loc
-    b = (frag_size_max - frag_size_loc) / frag_size_scale  # fraction of range greater than loc
+    a = (frag_size_min - frag_size_loc) / frag_size_sd  # fraction of range smaller than loc
+    b = (frag_size_max - frag_size_loc) / frag_size_sd  # fraction of range greater than loc
     refs.loc[:,'Frag_size'] = truncnorm.rvs(a, b,
                                             size=n_frags,
                                             loc=frag_size_loc,
-                                            scale=frag_size_scale)
+                                            scale=frag_size_sd)
     return refs
     
 def parse_frags(refs, barcode, out_dir):
